package com.fjhx.config;

import com.fjhx.config.exception.ServiceException;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;

import java.util.concurrent.Executor;
import java.util.concurrent.ThreadPoolExecutor;

/**
 * 线程池配置
 */
@EnableAsync
@Configuration
public class TaskPoolConfig {

    /**
     * 同步邮件
     */
    public static final String SYNC_MAILBOX_EXECUTOR = "syncMailboxExecutor";

    /**
     *
     */
    public static final String EXECUTOR = "executor";

    @Bean(name = SYNC_MAILBOX_EXECUTOR)
    public Executor syncMailboxExecutor() {
        ThreadPoolTaskExecutor executor = new ThreadPoolTaskExecutor();
        // 配置核心线程数
        executor.setCorePoolSize(5);
        // 配置最大线程数
        executor.setMaxPoolSize(10);
        // 配置队列大小
        executor.setQueueCapacity(10);
        // 缓冲队列大小
        executor.setKeepAliveSeconds(10);
        // 配置线程池中的线程的名称前缀
        executor.setThreadNamePrefix("async-syncMailboxExecutor:");
        // 线程池对拒绝任务的处理策略：抛出异常
        executor.setRejectedExecutionHandler((r, tempExecutor) -> {
            throw new ServiceException("系统繁忙，请稍后再试");
        });
        // 执行初始化
        executor.initialize();
        return executor;
    }

    @Bean(name = EXECUTOR)
    public Executor executor() {
        ThreadPoolTaskExecutor executor = new ThreadPoolTaskExecutor();
        // 配置核心线程数
        executor.setCorePoolSize(10);
        // 配置最大线程数
        executor.setMaxPoolSize(100);
        // 配置队列大小
        executor.setQueueCapacity(100);
        // 缓冲队列大小
        executor.setKeepAliveSeconds(100);
        // 配置线程池中的线程的名称前缀
        executor.setThreadNamePrefix("async-executor:");
        // 线程池对拒绝任务的处理策略：由调用线程（提交任务的线程）处理该任务
        executor.setRejectedExecutionHandler(new ThreadPoolExecutor.CallerRunsPolicy());
        // 执行初始化
        executor.initialize();
        return executor;
    }

}
