package com.fjhx.config.redis;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.connection.RedisConnectionFactory;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.serializer.RedisSerializer;
import org.springframework.data.redis.serializer.StringRedisSerializer;

/**
 * redis配置
 */

@Configuration
@SuppressWarnings(value = "All")
public class RedisConfig {

    @Bean
    public RedisSerializer<Object> fastJson2JsonRedisSerialize() {
        return new FastJsonRedisSerialize<>(Object.class);
    }

    @Bean
    public RedisTemplate<String, Object> redisTemplate(RedisConnectionFactory redisConnectionFactory) {

        RedisTemplate<String, Object> redisTemplate = new RedisTemplate<>();
        StringRedisSerializer stringRedisSerializer = new StringRedisSerializer();

        redisTemplate.setConnectionFactory(redisConnectionFactory);
        // key采用String的序列化方式
        redisTemplate.setKeySerializer(stringRedisSerializer);
        // hash的key也采用String的序列化方式
        redisTemplate.setHashKeySerializer(stringRedisSerializer);
        // value序列化方式采用fastJson
        redisTemplate.setValueSerializer(fastJson2JsonRedisSerialize());
        // hash的value序列化方式采用fastJson
        redisTemplate.setHashValueSerializer(fastJson2JsonRedisSerialize());

        redisTemplate.afterPropertiesSet();

        return redisTemplate;
    }

}
