package com.fjhx.service.impl;

import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fjhx.config.TaskPoolConfig;
import com.fjhx.config.exception.ServiceException;
import com.fjhx.entity.EmailMessage;
import com.fjhx.entity.EmailMessageContent;
import com.fjhx.mapper.EmailMessageContentMapper;
import com.fjhx.service.IEmailMessageContentService;
import com.fjhx.service.IEmailMessageService;
import com.fjhx.utils.EmailEngineUtil;
import com.fjhx.vo.MessageDetailVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import java.util.concurrent.Executor;

/**
 * <p>
 * 邮件正文 服务实现类
 * </p>
 *
 * @author zlj
 * @since 2023-01-10
 */
@Service
public class EmailMessageContentServiceImpl extends ServiceImpl<EmailMessageContentMapper, EmailMessageContent> implements IEmailMessageContentService {

    @Qualifier(TaskPoolConfig.EXECUTOR)
    @Autowired
    private Executor syncExecutor;

    @Autowired
    private IEmailMessageService emailMessageService;

    @Override
    public String getContent(String email, String messageId) {
        EmailMessageContent content = getById(messageId);


        try {
            if (content == null) {
                // 正文内容
                MessageDetailVo messageDetail = EmailEngineUtil.getMessageDetail(email, messageId);
                MessageDetailVo.TextDTO text = messageDetail.getText();
                String html = "";
                if (ObjectUtils.isNotEmpty(text)) {
                    html = text.getHtml();
                }

                String syncHtml = html;
                syncExecutor.execute(() -> {

                    AccountServiceImpl.syncMessageContentList.remove(email + "," + messageId);

                    EmailMessageContent emailMessageContent = new EmailMessageContent();
                    emailMessageContent.setMessageId(messageId);
                    emailMessageContent.setHtmlContent(syncHtml);
                    saveOrUpdate(emailMessageContent);

                    EmailMessage emailMessage = new EmailMessage();
                    emailMessage.setMessageId(messageId);
                    emailMessage.setContentSync(true);
                    emailMessage.setUnseen(false);
                    emailMessageService.updateById(emailMessage);

                });

                return html;

            }
        } catch (Exception e) {
            throw new ServiceException("获取邮件正文失败");
        }

        return content.getHtmlContent();
    }
}
